@@ -256,7 +256,7 @@
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.22-22/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.22-22/plugin/keyring_vault/tests;/build/percona-server/src/percona-server-5.7.22-22/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.22-22/plugin/scalability_metrics/tests"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.23-23/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.23-23/plugin/keyring_vault/tests;/build/percona-server/src/percona-server-5.7.23-23/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.23-23/plugin/scalability_metrics/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/doc/percona-server"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/doc/percona-server"
@@ -294,7 +294,7 @@
  * Character sets
  */
 #define MYSQL_DEFAULT_CHARSET_NAME "utf8mb4"
-#define MYSQL_DEFAULT_COLLATION_NAME "utf8mb4_unicode_ci"
+#define MYSQL_DEFAULT_COLLATION_NAME "utf8mb4_general_ci"
 /* #undef HAVE_CHARSET_armscii8 */
 /* #undef HAVE_CHARSET_ascii */
 #define HAVE_CHARSET_big5 1
@@ -393,15 +393,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 22
-#define MYSQL_VERSION_EXTRA "-22"
+#define MYSQL_VERSION_PATCH 23
+#define MYSQL_VERSION_EXTRA "-23"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.22-22"
+#define PACKAGE_STRING "MySQL Server 5.7.23-23"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.22-22"
-#define VERSION "5.7.22-22"
+#define PACKAGE_VERSION "5.7.23-23"
+#define VERSION "5.7.23-23"
 #define PROTOCOL_VERSION 10
 
 /*
